==> githubdepchecker-1.0.0.tar.gz: githubdepchecker-1.0.0/setup.py <==
# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from distutils.util import convert_path
from os import path

here = path.abspath(path.dirname(__file__))

# version = {}
# with open(here + '/depcheck/version.py') as fv:
#     exec(fv.read(), version)

short_description = (
    "CLI Tools to check dependencies of github repositories")

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='githubdepchecker',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version="1.0.0",

    description=short_description,
    long_description=long_description,
    long_description_content_type='text/markdown',

    # The project's main homepage.
    url='https://github.com/dyte-submissions/dyte-vit-2022-Shubh0405',

    # project_urls={
    #     'Documentation': 'https://github.com/dyte-submissions/dyte-vit-2022-Shubh0405',
    #     'Source': 'https://github.com/dyte-submissions/dyte-vit-2022-Shubh0405',
    #     'Release notes': 'https://github.com/dyte-submissions/dyte-vit-2022-Shubh0405',
    #     'Tracker': 'https://github.com/dyte-submissions/dyte-vit-2022-Shubh0405',
    # },

    # Author details
    author='Shubh Gupta',
    author_email='shubhngupta04@gmail.com',

    # Choose your license
    license='Apache License 2.0',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 5 - Production/Stable',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'Topic :: System :: Shells',
        'Topic :: Utilities',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: Apache Software License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10'
    ],

    # What does your project relate to?
    keywords='cli,github,npm,node',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    # packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    packages=find_packages(exclude=['tests', 'tests.*']),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    python_requires='>=3.7',
    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=['requests'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    extras_require={
        'dev': [
            'setuptools',
            'twine',
            'wheel'
        ]
    },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    package_data={
        'depcheck': ['config.json']
    },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('my_data', ['data/data_file'])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'depcheck=depcheck.depcheck:main'
        ]
    },
)

==> githubdepchecker-1.0.1.tar.gz: githubdepchecker-1.0.1/setup.py <==

from setuptools import setup, find_packages

from codecs import open
from distutils.util import convert_path
from os import path

here = path.abspath(path.dirname(__file__))

short_description = (
    "CLI Tool to check the dependencies of github repositories and create a pull request if packages need to get updated.")


with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='githubdepchecker',
    version="1.0.1",

    description=short_description,
    long_description=long_description,
    long_description_content_type='text/markdown',

    url='https://github.com/dyte-submissions/dyte-vit-2022-Shubh0405',

    author='Shubh Gupta',
    author_email='shubhngupta04@gmail.com',

    license='Apache License 2.0',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'Topic :: System :: Shells',
        'Topic :: Utilities',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10'
    ],

    packages=find_packages(exclude=['tests', 'tests.*']),

    # What does your project relate to?
    keywords='github,pull-requests,npm,npm-packages,cli-tool',

    python_requires='>=3.7',
    
    
    install_requires=['requests'],

   
    extras_require={
        'dev': [
            'setuptools',
            'twine',
            'wheel'
        ]
    },

   
    package_data={
        'githubdepchecker': ['config.json']
    },

    
    entry_points={
        'console_scripts': [
            'githubdepchecker=githubdepchecker.githubdepchecker:main'
        ]
    },
)
